from fastapi import APIRouter, status, HTTPException
from schemas.contact import ContactSchema, ContactCreate
from helpers.contact_helpers import validate_contact_data, create_contact
from sqlalchemy.orm import Session
from fastapi import Depends
from core.database import get_db

router = APIRouter()

@router.post("/contact", status_code=status.HTTP_201_CREATED, response_model=ContactSchema)
async def create_contact_entry(contact_data: ContactCreate, db: Session = Depends(get_db)):
    if not validate_contact_data(contact_data):
        raise HTTPException(status_code=400, detail="Invalid contact data")
    new_contact = create_contact(db=db, contact_data=contact_data)
    return new_contact