from fastapi import APIRouter, Depends, status
from sqlalchemy.orm import Session
from typing import List
from core.database import get_db
from schemas.toy import ToySchema, ToyCreate
from helpers.toy_helpers import get_all_toys, create_toy

router = APIRouter()

@router.post("/toys", status_code=status.HTTP_201_CREATED, response_model=ToySchema)
async def create_new_toy(
    toy: ToyCreate,
    db: Session = Depends(get_db)
):
    """Create a new toy"""
    new_toy = create_toy(db=db, toy_data=toy)
    return new_toy

@router.get("/toys", status_code=200, response_model=List[ToySchema])
async def get_toys(
    db: Session = Depends(get_db)
):
    """Get all toys"""
    toys = get_all_toys(db)
    return toys