import re
from sqlalchemy.orm import Session
from models.contact import Contact
from schemas.contact import ContactCreate

def validate_contact_data(contact_data: ContactCreate) -> bool:
    """
    Validates the contact data.

    Args:
        contact_data (ContactCreate): The contact data to validate.

    Returns:
        bool: True if the data is valid, False otherwise.
    """
    if not contact_data.name or not contact_data.email or not contact_data.message:
        return False
    if not re.match(r"[^@]+@[^@]+\.[^@]+", contact_data.email):
        return False
    return True

def create_contact(db: Session, contact_data: ContactCreate) -> Contact:
    """
    Creates a new contact in the database.

    Args:
        db (Session): The database session.
        contact_data (ContactCreate): The data for the contact to create.

    Returns:
        Contact: The newly created contact object.
    """
    if not validate_contact_data(contact_data):
        raise ValueError("Invalid contact data")
    db_contact = Contact(**contact_data.dict())
    db.add(db_contact)
    db.commit()
    db.refresh(db_contact)
    return db_contact