from pydantic import BaseModel, Field
from typing import Optional
from datetime import datetime
from uuid import UUID

class BookBase(BaseModel):
    title: str = Field(..., description="Book title")
    author: str = Field(..., description="Book author")
    description: Optional[str] = Field(None, description="Book description")
    isbn: str = Field(..., description="Book ISBN")
    pages: int = Field(..., gt=0, description="Number of pages")
    publisher_id: UUID = Field(..., description="Publisher ID")

class BookCreate(BookBase):
    pass

class BookUpdate(BookBase):
    title: Optional[str] = Field(None, description="Book title")
    author: Optional[str] = Field(None, description="Book author")
    description: Optional[str] = Field(None, description="Book description")
    isbn: Optional[str] = Field(None, description="Book ISBN")
    pages: Optional[int] = Field(None, gt=0, description="Number of pages")
    publisher_id: Optional[UUID] = Field(None, description="Publisher ID")

class BookSchema(BookBase):
    id: UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True