from pydantic import BaseModel, Field
from typing import Optional
from datetime import datetime
from uuid import UUID

class PlaylistBase(BaseModel):
    name: str = Field(..., min_length=1, description="Playlist name")
    description: Optional[str] = Field(None, description="Playlist description")

class PlaylistCreate(PlaylistBase):
    user_id: UUID = Field(..., description="User ID")

class PlaylistUpdate(PlaylistBase):
    name: Optional[str] = Field(None, min_length=1, description="Playlist name")
    description: Optional[str] = Field(None, description="Playlist description")

class PlaylistSchema(PlaylistBase):
    id: UUID
    created_at: datetime
    updated_at: datetime
    user_id: UUID

    class Config:
        orm_mode = True

class PlaylistSongBase(BaseModel):
    playlist_id: UUID = Field(..., description="Playlist ID")
    song_id: UUID = Field(..., description="Song ID")

class PlaylistSongCreate(PlaylistSongBase):
    pass

class PlaylistSongUpdate(PlaylistSongBase):
    pass

class PlaylistSongSchema(PlaylistSongBase):
    id: UUID
    created_at: datetime
    updated_at: datetime

    class Config:
        orm_mode = True